@@ -2,25 +2,37 @@
 #define ENTRY_H
 
 #include <QObject>
-
+#include <QStringList>
 //! [0]
 class Entry: public QObject
 {
+public:
+    static QStringList listCatoriseAvailMens;
+
     Q_OBJECT
 public slots:
-    void changedCategory(QString);
+    void changedCategory(int);
 
 public:
     Entry();
+
     void setName(QString);
+    void setDesktopName(QString);
     void setIconPath(QString);
+    void setTextDomain(QString);
     void setActualCategory(QString);
+
     QString getName();
+    QString getDesktopName();
     QString getIconPath();
+    QString getTextDomain();
     QString getActualCategory();
+
 private:
     QString name;
+    QString desktopName;
     QString iconPath;
+    QString textDomain;
     QString actualCategory;
 
 };
