@@ -23,12 +23,14 @@ QT_END_NAMESPACE
 class Mainmenu : public QMainWindow
 {
     Q_OBJECT
-
+    Q_CLASSINFO("D-Bus Interface", "com.nokia.catorisegui")
 private slots:
     void showAbout();
     void saveMenuFile();
     void updateProgressDialog();
     void resetProgressDialog();
+public slots:
+    Q_SCRIPTABLE int top_application();
 public:
     Mainmenu();
 
@@ -43,23 +45,25 @@ private:
 
 
     QStringList listCatoriseMenEntries;
-    QStringList listCatoriseAvailMens;
     QStringList listPossibleIconDirs;
     QList<QLabel *> *listLabels;
     QList<QComboBox *> *listCBoxes;
     QList<Entry *> *listEntries;
-
     QProcess *proc;
     QDirIterator *it;
 
-    QString getIconName(QString desktopName);
     QString getIconPath(QString iconName);
 
     void createMenu();
     void readMenuFile();
+    void generateEntries();
+    void readDesktopFileInformation(Entry *);
+    void putEntriesToLayout();
+
     void getPossibleIconDirs();
     void showInformationBox(QString information);
 
+
 };
 //! [0]
 
